Skip to contents

This function checks the input of naivePLS function.

Usage

assert_multivariate_naivePLS_inputs(
  df_list,
  Y,
  regul_time_obj = NULL,
  curve_type_obj = NULL,
  id_col_obj = "id",
  time_col_obj = "time"
)

Arguments

df_list

a list of dataframe (id, time, value_or_state)

Y

a numeric vector

regul_time_obj

a list of time regularisation values

curve_type_obj

a list of curve type 'cat' or 'num'

id_col_obj

a list of the names of the id columns

time_col_obj

a list of the names of the time columns

Value

a list

Author

Francois Bassac