This function checks the integrity of the input for multivariate_fpls. It returns a list of (basis_list, regul_time_list, curve_type_list, id_col_list, time_col_list)
Usage
assert_multivariate_smoothPLS_inputs(
df_list,
Y,
basis_obj,
regul_time_obj = NULL,
curve_type_obj = NULL,
orth_obj = list(TRUE),
id_col_obj = "id",
time_col_obj = "time"
)Arguments
- df_list
a list of dataframes (id, time, value_or_state)
- Y
a numeric vector of the response
- basis_obj
a list of basis object or a basis object
- regul_time_obj
a vector of time regularization values or a list of vectors
- curve_type_obj
a character "cat" or 'num' or a list of those values
- orth_obj
a boolean, a list or a vector of boolean to orthonormalize or not a basis
- id_col_obj
a character of the id column for all the curves or a list of id column character
- time_col_obj
a character of the time column for all the curves or a list of time column character