Skip to contents

This function preprocess the different input in order to format them to the right number of curve. Warning the "right" number of curve take into account the number of different states for the CFDs.

Usage

build_new_data_list(
  df_list,
  N_curves,
  orth_basis_list = NULL,
  basis_list = NULL,
  curve_type_list,
  id_col_list,
  time_col_list,
  regul_time_list
)

Arguments

df_list

a list of dataframes (id, time, value_or_state)

N_curves

a integer, the number of curves

orth_basis_list

a list of orthogonalized basis fd list

basis_list

a list of basis fd functions

curve_type_list

a list of the curve type of each curve

id_col_list

a list of the id column name for each curve

time_col_list

a list of the time column name for each curve

regul_time_list

a list of the time regularization vector for each curve

Value

a list

Author

Francois Bassac