Skip to contents

This function builds the smooth PLS regression functions.

Usage

build_reg_curve_spls(
  plsr_model,
  curves_names_list,
  v_i_list,
  nb_comp_pls_opt = NULL,
  print_steps = TRUE
)

Arguments

plsr_model

a pls model

curves_names_list

a list of the names of the different curves

v_i_list

a list of the v functions

nb_comp_pls_opt

a integer, the number of component to take into account. if null (default) all the components are used

print_steps

a boolean to print steps

Value

a list of fd object

Author

Francois Bassac