Skip to contents

This function build some intermediate functions of the smooth pls algorithm. It also evaluates the different coefficients gamma_ij

Usage

build_spls_functions(
  curves_names_list,
  new_basis_list,
  new_orth_basis_list,
  d_i,
  u_i
)

Arguments

curves_names_list

a list of the names of the different curves

new_basis_list

a list of the initial basis fd object for all curves

new_orth_basis_list

a list of the orthogonalized basis as fd list for all curves

d_i

the pls coefficient such as X = d_i t_i : plsr_model$loadings

u_i

the pls coefficient such as t_i = X u_i : plsr_model$loading.weights

Value

a list Lambda = sum d_i t_i

Author

Francois Bassac