Skip to contents

This function returns the min and max values of a list of functions and fd objects on regul_time.

Usage

eval_max_min_y(f_list, regul_time)

Arguments

f_list

a list of functions and fd objects

regul_time

a vector of time evaluation points.

Value

a vector

Author

Francois Bassac