This function evaluates the Lambda matrix Lambda_ij = int X_j(t) phi_i(t) dt using parallel processing with Chunking.
Usage
evaluate_lambda_CFD(
df,
basis,
int_mode = 1,
id_col = "id",
time_col = "time",
nb_pt = 10,
subdivisions = 100,
parallel = TRUE
)Arguments
- df
dataframe X(t)
- basis
basis fd object or a list of fd functions
- int_mode
integration mode, 1 for integrate, 2 for pracma::trapz
- id_col
a character for the id column, default 'id'
- time_col
a character for the time column, default 'time'
- nb_pt
number of points for the integration, default value : 10
- subdivisions
default parameter of R function integrate; default value : 100
- parallel
boolean, if TRUE uses max(nb_cores - 2, 1) cores, default TRUE.