Skip to contents

This function evaluates the Lambda matrix Lambda_ij = int X_j(t) phi_i(t) dt using parallel processing.

Usage

evaluate_lambda_CFD_para_v1(
  df,
  basis,
  int_mode = 1,
  id_col = "id",
  time_col = "time",
  nb_pt = 10,
  subdivisions = 100,
  parallel = TRUE
)

Arguments

df

dataframe X(t)

basis

basis fd object or a list of fd functions

int_mode

integration mode, 1 for integrate, 2 for pracma::trapz

id_col

a character for the id column, default 'id'

time_col

a character for the time column, default 'time'

nb_pt

number of points for the integration, default value : 10

subdivisions

default parameter of R function integrate; default value : 100

parallel

a boolean to enable parallel processing, default TRUE

Value

a matrix of dimension nbasis columns and nind rows

Author

Francois Bassac