Skip to contents

This function evaluates the Lambda matrix Lambda_ij = int X_j(t) phi_i(t) dt for step > 1 using parallel chunking.

Usage

evaluate_lambda_SFD(
  df,
  basis,
  regul_time = seq(basis$rangeval[1], basis$rangeval[2], 1),
  int_mode = 1,
  id_col = "id",
  time_col = "time",
  subdivisions = 100,
  parallel = TRUE
)

Arguments

df

dataframe X(t)

basis

basis fd object

regul_time

a vector of time regularization values default basis rangeval per 1

int_mode

int, integration mode, 1 for integrate, 2 for pracma::trapz

id_col

default name of the id column

time_col

default name of the time column

subdivisions

default parameter of R function integrate; default value : 100

parallel

boolean, if TRUE uses parallel processing. Default TRUE.

Value

a matrix of dimension nbasis columns and nind rows

Author

Francois Bassac