Skip to contents

This function transform a fd object into a function. It require either the fd object OR the coefficient and the basis object.

Usage

from_fd_to_func(fd_obj = NULL, coef = NULL, basisobj = NULL)

Arguments

fd_obj

a fd object to transform into a function

coef

the coefficient of an fd object to transform into a function

basisobj

the basis object of an fd object to transform into a function

Value

a function

Author

Francois Bassac

Examples

basis = create_bspline_basis(0, 100, 10, 4)
coef = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10)
func_from_fd = from_fd_to_func(coef = coef, basis = basis)