Skip to contents

This function assemble the metrics of all the basis of the basis list for multivariate use case. It take care on the categorical case by multiplying the basis per state.

Usage

multivariate_assemble_basis_metric(
  df_list,
  basis_list,
  curve_list,
  id_col_list,
  time_col_list
)

Arguments

df_list

a list of dataframe (id, time, value_or_state)

basis_list

a list of basis fd object

curve_list

a list of the curves type 'cat' or 'num'

id_col_list

a list of the character of the id columns

time_col_list

a list of the character of the time columns

Value

a matrix of the metric to consider

Author

Francois Bassac