Skip to contents

This function format the list of given dataframe into a time regularized matrix usable for the naivePLS function or prediction.

Usage

naivePLS_formatting(
  df_list,
  regul_time_obj = NULL,
  curve_type_obj = NULL,
  id_col_obj = "id",
  time_col_obj = "time"
)

Arguments

df_list

a list of dataframe of 3 columns (id, time, state_or_value)

regul_time_obj

a list of vector of time regularization values

curve_type_obj

a list of character of the type of curves

id_col_obj

a list of character for the id column names

time_col_obj

a list of character for the time column names

Value

a list

Author

Francois Bassacs