Skip to contents

This function orthonormalized a basis from a list if needed.

Usage

orthonormalize_basis_list(basis_list, orth_list, tol = 1e-09)

Arguments

basis_list

a list of basis to orthonormalized

orth_list

a list of boolean per basis if orthonormalization is needed

tol

a float, tolerance parameter.

Value

a list of list of fd object : the orthonormalized functions.

Author

Francois Bassac