Skip to contents

This function plots some histograms for train_results and test_results

Usage

plot_model_metrics_base(
  train_results,
  test_results,
  models_to_plot = c("FPLS", "SmoothPLS", "NaivePLS"),
  n_digits = 3
)

Arguments

train_results

a dataframe of train results

test_results

a dataframe of test results

models_to_plot

a list of characters of the models to plot, default c("FPLS", "SmoothPLS", "NaivePLS")

n_digits

a integer for the number of significant numbers to print, default 3

Value

a plot

Author

Francois Bassac