Skip to contents

This function return a list of functions of fd_list without the ones specified in the numeric vector toDrop.

Usage

select_from_fd_list(fd_list, toDrop = NULL)

Arguments

fd_list

a list of fd object

toDrop

a numeric vector

Value

a list of fd objects

Author

Francois Bassac