Skip to contents

Predicts the response variable for Categorical Functional Data (CFD) by integrating the regression coefficient function over active state intervals.

Usage

smoothPLS_CFD_predict(
  df_predict,
  delta_spls,
  id_col = "id",
  time_col = "time",
  subdivisions = 100,
  parallel = TRUE,
  ...
)

Arguments

df_predict

Dataframe containing columns for id, time, and state.

delta_spls

A list containing the scalar intercept and the functional regression coefficient (fd object).

id_col

Character, name of the id column, default 'id'.

time_col

Character, name of the time column, default 'time'.

subdivisions

integer, maximum number of sub-intervals for integration, default 100

parallel

a boolean to enable parallel processing, default TRUE.

...

Additional parameters passed to evaluate_id_func_integral (e.g., rel_tol, subdivisions).

Value

A numeric vector of predicted values for each individual.

Author

Francois Bassac