This function determines the curves names bases on its place in the data and
its states if it is a categorical functional data.
Usage
determine_curve_name(curve_number, curve_type = NULL, states_names = NULL)
Arguments
- curve_number
a int, the place of the curve in the data
- curve_type
a character, 'cat' or 'num'
- states_names
a character or list of character with the states of the CFD