R/general_functions.R
eval_max_min_y.Rd
This function returns the min and max values of a list of functions and fd objects on regul_time.
eval_max_min_y(f_list, regul_time)
a list of functions and fd objects
a vector of time evaluation points.
a vector
Francois Bassac