Either for R func or fd function, this function evaluates the distance
between the real curve and each curve fun or fd which are in the
func_fd_list.
Usage
evaluate_curves_distances(real_f, regul_time, fun_fd_list = NULL)
Arguments
- real_f
a fun of fd function, base function to compare
- regul_time
a vector of time regularization values
- fun_fd_list
a list of fun or fd functions or a fun or a fd function