This functions evaluates the regression function such as :
\(Y = \int_0^T delta(t) X(t) dt\).
Usage
evaluate_reg_curve_SPLS_uni(plsr_model, v_i_list, nb_comp = NULL)
Arguments
- plsr_model
a model from pls package
- v_i_list
a list of fd functions v_i(t) :
\(t_i = \int_0^T v_i(t) X(t) dt\)
- nb_comp
a value, number of components to take into account, default NULL
if NULL, then delta(t) will take every components available.