This function generates Y_df bases on df, beta_func with the following link Y = beta_0 + int(X(t)*beta(t))dt It generates also the noised values of Y. Here the NotS_ratio is the Noise over total Signal ratio meaning that a value of 0.2 means that the noise represents 20% of the TOTAL variance.
Usage
generate_Y_df_SFD(
df,
beta_real_func,
beta_0_real = 5.4321,
NotS_ratio = 0.2,
id_col = "id",
time_col = "time",
seed = 123
)Arguments
- df
the X(t) dataframe to evaluate Y on
- beta_real_func
a function beta(t), function used for the Y evaluation
- beta_0_real
the intercept, default 5.4321
- NotS_ratio
the Noise over total Signal ratio, default 0.2
- id_col
a character of the id column, default 'id'
- time_col
a character of the time column, default 'time'
- seed
a integer, random seed, 123