This function builds the alphas matrix by columns binding the alpha of each curve. It returns the alphas matrix and a vector containing all the curves names.
Usage
multivariate_alpha_building(
df_list,
basis_list,
curve_type_list,
regul_time_list,
id_col_list,
time_col_list,
print_steps = FALSE
)Arguments
- df_list
a list of data frame (id, time, state_or_value)
- basis_list
a list of basis
- curve_type_list
a list of curves
- regul_time_list
a list of regul_time
- id_col_list
a list if the characters for the id column
- time_col_list
a list of the characters for the time column
- print_steps
a boolean to print the current step, default FALSE