R/general_functions.R
select_from_fd_list.Rd
This function return a list of functions of fd_list without the ones specified in the numeric vector toDrop.
select_from_fd_list(fd_list, toDrop = NULL)
a list of fd object
a numeric vector
a list of fd objects
Francois Bassac